@@ -2,7 +2,6 @@ import datetime
 import io
 
 import requests
-from PyPDF2 import PdfFileMerger
 from django import forms
 from django.conf import settings
 from django.contrib import messages
@@ -14,8 +13,7 @@ from django.db.models import F
 from django.db.models.deletion import ProtectedError
 from django.http.response import HttpResponseRedirect, HttpResponse
 from django.shortcuts import redirect
-from django.urls import reverse
-from django.utils import timezone, six
+from django.utils import timezone
 from django.utils.text import slugify
 from django.utils.translation import ugettext_lazy as _, ugettext
 
@@ -78,14 +76,24 @@ class StaffRequiredMixin(AccessMixin):
             raise PermissionDenied(self.get_permission_denied_message())
 
         messages.error(self.request, self.get_permission_denied_message())
-        return redirect(getattr(settings, 'LOGIN_REDIRECT_URL', reverse('dashboard')))
+        return redirect(getattr(settings, 'LOGIN_REDIRECT_URL', '/'))
+
+
+class SuperuserRequiredMixin(StaffRequiredMixin):
+    """
+    CBV mixin which verifies that the current user is superuser
+    """
+    def dispatch(self, request, *args, **kwargs):
+        if not request.user.is_superuser:
+            return self.handle_no_permission()
+        return super(SuperuserRequiredMixin, self).dispatch(request, *args, **kwargs)
 
 
 class DeleteObjectMixin(object):
     template_name = 'confirm_delete.html'
-    title = _(u'Delete object')
-    message_success = _(u'Object successfully deleted.')
-    message_error = _(u'Object could not be deleted, check if some objects are not associated with it.')
+    title = _('Delete object')
+    message_success = _('Object successfully deleted.')
+    message_error = _('Object could not be deleted, check if some objects are not associated with it.')
     back_url = None
     failure_url = None
 
@@ -193,8 +201,8 @@ class FPDFMixin(object):
     ORIENTATION_PORTRAIT = 'P'
     ORIENTATION_LANDSCAPE = 'L'
     ORIENTATIONS = (
-        (ORIENTATION_PORTRAIT, _(u'Portrait')),
-        (ORIENTATION_LANDSCAPE, _(u'Landscape'))
+        (ORIENTATION_PORTRAIT, _('Portrait')),
+        (ORIENTATION_LANDSCAPE, _('Landscape'))
     )
     orientation = ORIENTATION_PORTRAIT
     margin_left = 8
@@ -205,6 +213,12 @@ class FPDFMixin(object):
     def render(self, **kwargs):
         # Go through keyword arguments, and either save their values to our
         # instance, or raise an error.
+
+        try:
+            from django.utils import six
+        except ImportError:
+            import six
+
         for key, value in six.iteritems(kwargs):
             setattr(self, key, value)
 
@@ -383,6 +397,7 @@ class PdfDetailMixin(object):
         pdf_response = requests.post(api_url, data=html_content)
         buffer = io.BytesIO(pdf_response.content)
 
+        from PyPDF2 import PdfFileMerger
         pdf_merger = PdfFileMerger()
         pdf_merger.append(buffer)
         pdf_merger.addMetadata({'/Title': filename})
